# jQuery ColorPicker

- Basic <input>
- Basic element
- All features
- Localization
- Websafe colors
- Alternative display field
- Events
- Input formatting
- Output formatting
- Output format list
- In a dialog
- Modal
- Any element to popup

## Basic <input> example, without any options

## Basic element (<span>> example, without any options

## Fully-featured example

## Localized to Dutch (nl)

## Limit to websafe colors

## Alternative field class

Background-color on outside, text color here

## Events

## Output formatting HSLA

## Output format list

You can specify a list of output formats, the first perfect match for the color is output.

## Dialog with Colorpicker popup (demonstrates z-index)

Basic <input> example, without any options:
Basic element example, without any options:

## Modal (and showCancelButton, closeOnEscape, showCloseButton)

## Input formatting

Demonstrates the ability to parse common color formats as input.

## Popup from any element (<em>)

Just click on this Emphasized word to show the colorpicker.